@@ -43,6 +43,9 @@
 #ifdef _WIN32
 /* WIN32 needs <fcntl.h> for _O_BINARY */
 #include <fcntl.h>
+#ifndef STDIN_FILENO
+#define STDIN_FILENO _fileno(stdin)
+#endif
 #endif
 
 #ifndef HAVE_GETOPT
@@ -1061,7 +1064,7 @@ int
 main(int argc, char *argv[])
 {
     const char *archive;
-    zip_source_t *memory_src;
+    zip_source_t *memory_src = NULL;
     unsigned int i;
     int c, arg, err, flags;
     const char *prg;
